package de.szut.casino.security.service;

import de.szut.casino.user.UserEntity;
import jakarta.mail.MessagingException;
import jakarta.mail.internet.MimeMessage;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.ClassPathResource;
import org.springframework.mail.javamail.JavaMailSenderImpl;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.stereotype.Service;
import org.springframework.util.FileCopyUtils;

import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.nio.charset.StandardCharsets;

@Service
public class EmailService {
    private JavaMailSenderImpl mailSender;
    private MailConfig mailConfig;
    @Value("${app.frontend-host}")
    private String feUrl;

    public EmailService(JavaMailSenderImpl mailSender, MailConfig mailConfig) {
        this.mailSender = mailSender;
        this.mailConfig = mailConfig;
        this.mailSender.setHost(mailConfig.host);
        this.mailSender.setPort(mailConfig.port);
        if (mailConfig.authenticationEnabled) {
            this.mailSender.setUsername(mailConfig.username);
            this.mailSender.setPassword(mailConfig.password);
        }
    }

    public void sendRegistrationEmail(UserEntity user) throws IOException, MessagingException {
        String template = loadTemplate("email/welcome.html");
        String htmlContent = template
                .replace("${username}", user.getUsername())
                .replace("${feUrl}", feUrl);

        MimeMessage message = mailSender.createMimeMessage();
        MimeMessageHelper helper = new MimeMessageHelper(message, true, "UTF-8");

        helper.setFrom(mailConfig.fromAddress);
        helper.setTo(user.getEmail());
        helper.setSubject("Willkommen bei Trustworthy Casino©");
        helper.setText(htmlContent, true);

        mailSender.send(message);
    }

    private String loadTemplate(String templatePath) throws IOException {
        ClassPathResource resource = new ClassPathResource("templates/" + templatePath);
        try (Reader reader = new InputStreamReader(resource.getInputStream(), StandardCharsets.UTF_8)) {
            return FileCopyUtils.copyToString(reader);
        }
    }
}
